@@ -6,20 +6,17 @@ import requests
 
 
 def create_scope(user_name):
-    dbutils = resolve_dbutils()
-    dbx_token = get_token(dbutils)
+    dbx_token = get_token()
     auth_header = {"authorization": f"Bearer {dbx_token}"}
     dbx_url = get_host()
     scope_name = user_name.split('@')[0]        # scope name is the first half of user name before @
     create_scope_api = f"{dbx_url}/api/2.0/secrets/scopes/create"
     create_scope_data = json.dumps({'scope': scope_name})
-    response = requests.post(create_scope_api, headers=auth_header, data=create_scope_data)
-    response.content
+    requests.post(create_scope_api, headers=auth_header, data=create_scope_data)
 
 
 def put_user_acl(user_name):
-    dbutils = resolve_dbutils()
-    dbx_token = get_token(dbutils)
+    dbx_token = get_token()
     auth_header = {"authorization": f"Bearer {dbx_token}"}
     dbx_url = get_host()
     scope_name = user_name.split('@')[0]
@@ -29,23 +26,21 @@ def put_user_acl(user_name):
         "principal": user_name,
         "permission": "MANAGE"
     })
-    response = requests.post(put_acl_api, headers = auth_header, data= put_acl_data)
-    response.content
+    requests.post(put_acl_api, headers = auth_header, data= put_acl_data)
 
 
 def remove_service_account(user_name):
-    scope_name = user_name.split('@')[0]
-    dbutils = resolve_dbutils()
-    dbx_token = get_token(dbutils)
-    auth_header = {"authorization": f"Bearer {dbx_token}"}
-    dbx_url = get_host()
-    delete_acl_api = f"{dbx_url}/api/2.0/secrets/acls/delete"
-    delete_acl_data = json.dumps({
-      "scope": scope_name,
-      "principal": get_username()
-    })
-    response = requests.post(delete_acl_api, headers = auth_header, data= delete_acl_data)
-    response.content
+    if user_name != get_username():
+        scope_name = user_name.split('@')[0]
+        dbx_token = get_token()
+        auth_header = {"authorization": f"Bearer {dbx_token}"}
+        dbx_url = get_host()
+        delete_acl_api = f"{dbx_url}/api/2.0/secrets/acls/delete"
+        delete_acl_data = json.dumps({
+          "scope": scope_name,
+          "principal": get_username()
+        })
+        requests.post(delete_acl_api, headers = auth_header, data= delete_acl_data)
 
 
 def get_secret_name(secret):
@@ -62,28 +57,33 @@ def create_scope_if_not_exists():
     spark = SparkSession.getActiveSession()
     df = spark.sql("SHOW USERS")
     df_list_of_users = df.rdd.map(lambda x: x.name).collect()
-    users_to_have_scopes = [item for items in df_list_of_users for item in items.split('@')][::2]
 
     scope_names = list(map(lambda x: x.name, dbutils.secrets.listScopes()))
 
-    users_to_create_scopes = set(users_to_have_scopes) - set(scope_names)
-
-    for user_name in users_to_create_scopes:
-        create_scope(user_name)
-        put_user_acl(user_name)
-        if user_name != get_username:
+    for user_name in df_list_of_users:
+        scope_name = user_name.split('@')[0]
+        if scope_name not in scope_names:
+            create_scope(user_name)
+            put_user_acl(user_name)
             remove_service_account(user_name)
 
 
 def add_secret(secret_name, secret_value, secret_scope=None):
     if secret_scope is None:
         secret_scope = get_scope_name()
-    dbutils = resolve_dbutils()
-    dbx_token = get_token(dbutils)
+    dbx_token = get_token()
     auth_header = {"authorization": f"Bearer {dbx_token}"}
     dbx_url = get_host()
     create_scope_api = f"{dbx_url}/api/2.0/secrets/put"
     put_secret_data = json.dumps({'scope': secret_scope, 'key': secret_name, 'string_value': secret_value})
     return requests.post(create_scope_api, headers=auth_header, data=put_secret_data).content
 
-
+def remove_secret(secret_name, secret_scope=None):
+    if secret_scope is None:
+        secret_scope = get_scope_name()
+    dbx_token = get_token()
+    auth_header = {"authorization": f"Bearer {dbx_token}"}
+    dbx_url = get_host()
+    remove_secret_api = f"{dbx_url}/api/2.0/secrets/delete"
+    remove_secret_data = json.dumps({'scope': secret_scope, 'key': secret_name})
+    return requests.post(remove_secret_api, headers=auth_header, data=remove_secret_data).content
